@@ -86,7 +86,7 @@
 #define KIOCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIOCORE_NO_DEPRECATED
-#  define KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56400
+#  define KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56500
 #endif
 #ifdef KIOCORE_NO_DEPRECATED_WARNINGS
 #  define KIOCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIOCORE_DEPRECATED_WARNINGS_SINCE KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIOCORE_DEPRECATED_WARNINGS_SINCE 0x56400
+#    define KIOCORE_DEPRECATED_WARNINGS_SINCE 0x56500
 #  endif
 #endif
 
@@ -325,6 +325,12 @@
 #else
 #  define KIOCORE_DEPRECATED_VERSION_5_100(text)
 #endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x56500
+#  define KIOCORE_DEPRECATED_VERSION_5_101(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_101(text)
+#endif
 #define KIOCORE_DEPRECATED_VERSION_3(minor, text)      KIOCORE_DEPRECATED_VERSION_3_##minor(text)
 #define KIOCORE_DEPRECATED_VERSION_4(minor, text)      KIOCORE_DEPRECATED_VERSION_4_##minor(text)
 #define KIOCORE_DEPRECATED_VERSION_5(minor, text)      KIOCORE_DEPRECATED_VERSION_5_##minor(text)
@@ -392,7 +398,7 @@
 #define KIOCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIOCORE_NO_DEPRECATED
-#  define KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56400
+#  define KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56500
 #endif
 #ifdef KIOCORE_NO_DEPRECATED_WARNINGS
 #  define KIOCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -402,7 +408,7 @@
 #  ifdef KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIOCORE_DEPRECATED_WARNINGS_SINCE KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIOCORE_DEPRECATED_WARNINGS_SINCE 0x56400
+#    define KIOCORE_DEPRECATED_WARNINGS_SINCE 0x56500
 #  endif
 #endif
 
@@ -631,6 +637,12 @@
 #else
 #  define KIOCORE_DEPRECATED_VERSION_5_100(text)
 #endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x56500
+#  define KIOCORE_DEPRECATED_VERSION_5_101(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_101(text)
+#endif
 #define KIOCORE_DEPRECATED_VERSION_3(minor, text)      KIOCORE_DEPRECATED_VERSION_3_##minor(text)
 #define KIOCORE_DEPRECATED_VERSION_4(minor, text)      KIOCORE_DEPRECATED_VERSION_4_##minor(text)
 #define KIOCORE_DEPRECATED_VERSION_5(minor, text)      KIOCORE_DEPRECATED_VERSION_5_##minor(text)
